getAsDouble method
Retrieves the element of key of type double from Map.
If Map does not have an element of key or the type does not match double, orElse is returned.
Implementation
double getAsDouble(K key, [double orElse = 0.0]) {
assert(key != null, "The key is empty.");
if (!containsKey(key) || this[key] is! num?) {
return orElse;
}
return (this[key] as num?)?.toDouble() ?? orElse;
}